DecapsulationKey512

Type Alias DecapsulationKey512 

pub type DecapsulationKey512 = DecapsulationKey;
An ML-KEM-512 DecapsulationKey which provides the ability to generate a new key pair, and decapsulate an encapsulated shared key.

Aliased Type

pub struct DecapsulationKey512 { /* private fields */ }