DecapsulationKey768

Type Alias DecapsulationKey768 

pub type DecapsulationKey768 = DecapsulationKey;
An ML-KEM-768 DecapsulationKey which provides the ability to generate a new key pair, and decapsulate an encapsulated shared key.

Aliased Type

pub struct DecapsulationKey768 { /* private fields */ }