EncapsulationKey1024

Type Alias EncapsulationKey1024 

pub type EncapsulationKey1024 = EncapsulationKey;
An ML-KEM-1024 EncapsulationKey provides the ability to encapsulate a shared key so that it can only be decapsulated by the holder of the corresponding decapsulation key.

Aliased Type

pub struct EncapsulationKey1024 { /* private fields */ }