EncapsulationKey

Struct EncapsulationKey 

pub struct EncapsulationKey<P>
where P: KemParams,
{ /* private fields */ }
An EncapsulationKey provides the ability to encapsulate a shared key so that it can only be decapsulated by the holder of the corresponding decapsulation key.

Implementations

Source

impl<P> EncapsulationKey<P>
where P: Kem<SharedKeySize = U32> + KemParams,

pub fn new(encapsulation_key: &Key<Self>) -> Result<Self, InvalidKey>

Create a new EncapsulationKey from its serialized form.

Errors

If the key failed validation during decoding.

pub fn encapsulate_deterministic(&self, m: &B32) -> (Ciphertext<P>, SharedKey)

Encapsulates with the given randomness. This is useful for testing against known vectors.

Warning

Do NOT use this function unless you know what you’re doing. If you fail to use all uniform random bytes even once, you can have catastrophic security failure.