DecapsulationKey1024

Type Alias DecapsulationKey1024 

pub type DecapsulationKey1024 = DecapsulationKey;
An ML-KEM-1024 DecapsulationKey which provides the ability to generate a new key pair, and decapsulate an encapsulated shared key.

Aliased Type

pub struct DecapsulationKey1024 { /* private fields */ }