pub type EncapsulationKey512 = EncapsulationKey;Expand description
An ML-KEM-512 EncapsulationKey provides the ability to encapsulate a shared key so that it
can only be decapsulated by the holder of the corresponding decapsulation key.
Aliased Type
pub struct EncapsulationKey512 { /* private fields */ }